# Supported Field Types for Fact Sheet Mapping
This document lists the supported field types from SAP LeanIX that can be mapped to Collibra attribute types.
The Collibra integration allows you to map fact sheet fields from SAP LeanIX to attributes on your assets in Collibra. The following field types from SAP LeanIX can be mapped to Collibra attribute types:
SAP LeanIX Field Types | Collibra Attribute Types
---|---
STRING | Text
SINGLE_SELECT |  Text Selection Multiple Selection
MULTIPLE_SELECT |  Text Multiple Selection
EXTERNAL_ID | Text
INTEGER / DOUBLE |  Number Text
LIFECYCLE | Text
LIFECYCLE's Phases Dates |  Text Date
LIFECYCLE's Current Phase (e.g., 'active') |  Text Selection Multiple Selection
LIFECYCLE's Upcoming Phase (e.g., 'phaseIn') |  Text Selection Multiple Selection
Quality Seal |  Text Selection
Fact Sheet URL | Text
Fact Sheet ID | Text


